@@ -12,7 +12,7 @@ use std::mem;
 use std::ops::Range;
 use std::slice::{Chunks, ChunksMut};
 use std::sync::{Arc, Mutex};
-use time::PrimitiveDateTime;
+use time::Instant;
 
 /// Calibration information which determines when multi threaded code will be used.
 #[derive(Debug, PartialEq)]
@@ -37,13 +37,13 @@ fn limit(value: usize, min: usize, max: usize) -> usize {
 }
 
 fn measure(number_of_cores: usize, data: &mut Vec<f64>) -> Result<f64, u32> {
-    let start = PrimitiveDateTime::now();
+    let start = Instant::now();
     Chunk::execute_on_chunks(&mut data[..], 1, (), number_of_cores, move |array, _arg| {
         for v in array {
             *v = v.sin();
         }
     });
-    let result = (PrimitiveDateTime::now() - start).whole_nanoseconds() as f64;
+    let result = start.elapsed().whole_nanoseconds() as f64;
     if result < 1000.0 {
         Err(1) // Likely the compiler optimized our benchmark code away so we have to work with defaults
     } else {
@@ -170,10 +170,10 @@ static LARGE_DUAL_CORE_DEFAULT: usize = 20_000;
 static LARGE_MULTI_CORE_DEFAULT: usize = 30_000;
 
 fn calibrate(number_of_cores: usize) -> Calibration {
-    let start = PrimitiveDateTime::now();
+    let start = Instant::now();
     match attempt_calibrate(number_of_cores) {
         Ok(mut calibration) => {
-            calibration.duration_cal_routine = ((PrimitiveDateTime::now() - start).whole_nanoseconds() as f64) / 1e9;
+            calibration.duration_cal_routine = (start.elapsed().whole_nanoseconds() as f64) / 1e9;
             calibration
         }
         Err(err_code) => Calibration {
@@ -181,7 +181,7 @@ fn calibrate(number_of_cores: usize) -> Calibration {
             med_multi_core_threshold: MED_MULTI_CORE_DEFAULT,
             large_dual_core_threshold: LARGE_DUAL_CORE_DEFAULT,
             large_multi_core_threshold: LARGE_MULTI_CORE_DEFAULT,
-            duration_cal_routine: ((PrimitiveDateTime::now() - start).whole_nanoseconds() as f64) / 1e9,
+            duration_cal_routine: (start.elapsed().whole_nanoseconds() as f64) / 1e9,
             cal_routine_result_code: err_code,
         },
     }
