@@ -1,7 +1,7 @@
 use super::{Simd, SimdFrom};
 use crate::numbers::*;
-pub use packed_simd::{f32x4, f64x2};
-use packed_simd::{i32x4, i64x2, FromCast};
+pub use packed_simd_2::{f32x4, f64x2};
+use packed_simd_2::{i32x4, i64x2, FromCast};
 use std::arch::x86_64::*;
 use std::mem;
 
