@@ -1,5 +1,5 @@
 mod complex_to_real;
 pub use self::complex_to_real::*;
 
-mod complex;
-pub use self::complex::*;
+mod complex_ops;
+pub use self::complex_ops::*;
